"""
Rexense WS client library init.
"""

__version__ = "0.1.3"

from .api import get_basic_info
from .const import (
    DEFAULT_PORT,
    VENDOR_CODE,
    API_VERSION,
    FUNCTION_GET_BASIC_INFO,
    FUNCTION_NOTIFY_STATUS,
    FUNCTION_INVOKE_CMD,
    REXENSE_SENSOR_CURRENT,
    REXENSE_SENSOR_VOLTAGE,
    REXENSE_SENSOR_POWER_FACTOR,
    REXENSE_SENSOR_ACTIVE_POWER,
    REXENSE_SENSOR_APPARENT_POWER,
    REXENSE_SENSOR_B_CURRENT,
    REXENSE_SENSOR_B_VOLTAGE,
    REXENSE_SENSOR_B_POWER_FACTOR,
    REXENSE_SENSOR_B_ACTIVE_POWER,
    REXENSE_SENSOR_B_APPARENT_POWER,
    REXENSE_SENSOR_C_CURRENT,
    REXENSE_SENSOR_C_VOLTAGE,
    REXENSE_SENSOR_C_POWER_FACTOR,
    REXENSE_SENSOR_C_ACTIVE_POWER,
    REXENSE_SENSOR_C_APPARENT_POWER,
    REXENSE_SENSOR_TOTAL_ACTIVE_POWER,
    REXENSE_SENSOR_TOTAL_APPARENT_POWER,
    REXENSE_SENSOR_CEI,
    REXENSE_SENSOR_CEE,
    REXENSE_SENSOR_A_CEI,
    REXENSE_SENSOR_A_CEE,
    REXENSE_SENSOR_B_CEI,
    REXENSE_SENSOR_B_CEE,
    REXENSE_SENSOR_C_CEI,
    REXENSE_SENSOR_C_CEE,
    REXENSE_SENSOR_TEMPERATURE,
    REXENSE_SENSOR_BATTERY_PERCENTAGE,
    REXENSE_SENSOR_BATTERY_VOLTAGE,
    REXENSE_SWITCH_ONOFF,
)
from .ws_client import RexenseWebsocketClient

__all__ = [
    "get_basic_info",
    "RexenseWebsocketClient",
    # constants
    "DEFAULT_PORT",
    "VENDOR_CODE",
    "API_VERSION",
    "FUNCTION_GET_BASIC_INFO",
    "FUNCTION_NOTIFY_STATUS",
    "FUNCTION_INVOKE_CMD",
    "REXENSE_SENSOR_CURRENT",
    "REXENSE_SENSOR_VOLTAGE",
    "REXENSE_SENSOR_POWER_FACTOR",
    "REXENSE_SENSOR_ACTIVE_POWER",
    "REXENSE_SENSOR_APPARENT_POWER",
    "REXENSE_SENSOR_B_CURRENT",
    "REXENSE_SENSOR_B_VOLTAGE",
    "REXENSE_SENSOR_B_POWER_FACTOR",
    "REXENSE_SENSOR_B_ACTIVE_POWER",
    "REXENSE_SENSOR_B_APPARENT_POWER",
    "REXENSE_SENSOR_C_CURRENT",
    "REXENSE_SENSOR_C_VOLTAGE",
    "REXENSE_SENSOR_C_POWER_FACTOR",
    "REXENSE_SENSOR_C_ACTIVE_POWER",
    "REXENSE_SENSOR_C_APPARENT_POWER",
    "REXENSE_SENSOR_TOTAL_ACTIVE_POWER",
    "REXENSE_SENSOR_TOTAL_APPARENT_POWER",
    "REXENSE_SENSOR_CEI",
    "REXENSE_SENSOR_CEE",
    "REXENSE_SENSOR_A_CEI",
    "REXENSE_SENSOR_A_CEE",
    "REXENSE_SENSOR_B_CEI",
    "REXENSE_SENSOR_B_CEE",
    "REXENSE_SENSOR_C_CEI",
    "REXENSE_SENSOR_C_CEE",
    "REXENSE_SENSOR_TEMPERATURE",
    "REXENSE_SENSOR_BATTERY_PERCENTAGE",
    "REXENSE_SENSOR_BATTERY_VOLTAGE",
    "REXENSE_SWITCH_ONOFF",
]